@@ -1,40 +1,81 @@
 
 # do a single conditional independence test.
-ci.test = function(x, ...) {
+ci.test = function(x, y, z, data, test, B, debug = FALSE) {
 
-  UseMethod("ci.test", x)
+  if (missing(x))
+    stop("one or both of the variables to test are missing.")
+
+  if (is.string(x)) {
+
+    ci.test.character(x = x, y = y, z = z, data = data, test = test, B = B,
+      debug = debug)
+
+  }#THEN
+  else if (is(x, c("matrix", "data.frame"))) {
+
+    if (!missing(y) || !missing(z))
+      warning("'y' and 'z' will be ignored.")
+    if (!missing(data))
+      warning("'data' will be ignored.")
+    if (ncol(x) < 2)
+      stop("'x' must have at least two columns.")
+
+    nodes = names(x)
+    ci.test.character(x = nodes[1], y = nodes[2], z = nodes[-(1:2)],
+      data = x, test = test, B = B, debug = debug)
+
+  }#THEN
+  else if (is.vector(x)) {
+
+    if (!missing(data))
+      warning("'data' will be ignored.")
+
+    ci.test.vector(x = x, y = y, z = z, xlab = deparse(substitute(x)),
+      ylab = deparse(substitute(y)), zlab = deparse(substitute(z)),
+      test = test, B = B, debug = debug)
+
+  }#THEN
+  else {
+
+    stop("x must be either a factor object, a numeric vector, a character string or a data frame.")
+
+  }#ELSE
 
 }#CI.TEST
 
 # do a single conditional independence test (nodes as character strings).
-ci.test.character = function(x, y = NULL, z = NULL, data, test = NULL,
-    B = NULL, debug = FALSE, ...) {
+ci.test.character = function(x, y, z, data, test, B, debug = FALSE) {
 
   # the original data set is needed.
   check.data(data)
   # check debug.
   check.logical(debug)
   # check the variables involved in the test.
-  if (!is.string(x) || !(x %in% names(data)))
+  if (missing(x) || missing(y))
+    stop("one or both of the variables to test are missing.")
+  if (!is.string(x) || (x %!in% names(data)))
     stop("'x' must be a character string, the name of one of the columns of 'data'.")
-  if (!is.string(y) || !(y %in% names(data)))
+  if (!is.string(y) || (y %!in% names(data)))
     stop("'y' must be a character string, the name of one of the columns of 'data'.")
   if (x == y)
     stop("'x' must be different from 'y'.")
-  if (!is.null(z)) {
+  if (!missing(z) && !identical(z, character(0))) {
 
-    if (!is.character(z) || !all(z %in% names(data)))
+    if (!is.string.vector(z) || any(z %!in% names(data)))
       stop("'z' must be a vector of character strings, the names of one or more of the columns of 'data'.")
-    if (any(z %in% c(x, y)))
+    if ((z == x) || (z == y))
       stop("'z' must be different from both 'x' and 'y'.")
 
   }#THEN
+  else {
+
+    z = character(0)
+
+  }#ELSE
   # check the test label.
-  test = check.test(test, data)
+  test = check.test(test, minimal.data.frame.column(data, c(x, y, z)))
   # check B (the number of permutation samples).
   B = check.B(B, test)
-  # warn about unused arguments.
-  check.unused.args(list(...), character(0))
 
   # create the htest object.
   htest = indep.test(x = x, y = y, sx = z, data = data, test = test,
@@ -47,55 +88,29 @@ ci.test.character = function(x, y = NULL, z = NULL, data, test = NULL,
 
 }#CI.TEST.CHARACTER
 
-# do a single conditional independence test (nodes in a matrix).
-ci.test.matrix = function(x, test = NULL, B = NULL, debug = FALSE, ...) {
-
-  if (ncol(x) < 2)
-    stop("'x' must have at least two columns.")
-
-  ci.test.data.frame(x = as.data.frame(x), test = test, B = B, debug = debug, ...)
-
-}#CI.TEST.MATRIX
-
-# do a single conditional independence test (nodes in a data frame).
-ci.test.data.frame = function(x, test = NULL, B = NULL, debug = FALSE, ...) {
-
-  if (ncol(x) < 2)
-    stop("'x' must have at least two columns.")
-
-  nodes = names(x)
-
-  # warn about unused arguments.
-  check.unused.args(list(...), character(0))
-
-  ci.test.character(x = nodes[1], y = nodes[2], z = nodes[-(1:2)],
-    data = x, test = test, B = B, debug = debug)
-
-}#CI.TEST.DATA.FRAME
-
-# do a single conditional independence test (numerical vectors).
-ci.test.numeric = function(x, y = NULL, z = NULL, test = NULL, B = NULL, debug = FALSE, ...) {
+# do a single conditional independence test (data vectors).
+ci.test.vector = function(x, y, z, xlab, ylab, zlab, test, B, debug = FALSE) {
 
   # check debug.
   check.logical(debug)
   # check the variables involved in the test.
-  if (!is.numeric(y) && !(is.matrix(y) && ncol(y) == 1))
-    stop("'y' must be a numeric vector.")
+  if (!is.vector(x))
+    stop("'y' must be a vector.")
+  if (!is.vector(y))
+    stop("'y' must be a vector.")
   if (length(y) != length(x))
     stop("'x' and 'y' must have the same length.")
-  if (!is.null(z)) {
+  if (!missing(z)) {
 
     if (is.matrix(z) || is.data.frame(z)) {
 
       if (nrow(z) != length(x))
         stop("'x', 'y', and 'z' must have the same length.")
-      if (data.type(z) != "continuous")
-        stop("'z' must be a numeric matrix or data frame.")
 
       sx = 3:(2 + ncol(z))
 
     }#THEN
-    else if (is.numeric(z)) {
+    else if (is.vector(z)) {
 
       if (length(z) != length(x))
         stop("'x', 'y', and 'z' must have the same length.")
@@ -114,101 +129,26 @@ ci.test.numeric = function(x, y = NULL, z = NULL, test = NULL, B = NULL, debug =
 
     # build the data frame.
     data = data.frame(x = x, y = y)
-
     sx = integer(0)
+    z = character(0)
 
   }#ELSE
+
   # check the data are there.
   check.data(data)
   # check the test label.
   test = check.test(test, data)
   # check B (the number of permutation samples).
   B = check.B(B, test)
-  # warn about unused arguments.
-  check.unused.args(list(...), character(0))
 
   # create the htest object.
   htest = indep.test(x = 1L, y = 2L, sx = sx, data = data,
     test = test, B = B, alpha = 1, learning = FALSE)
   htest$method = test.labels[test]
-  htest$data.name = paste(deparse(substitute(x)), "~", deparse(substitute(y)),
-        ifelse(!is.null(z), paste("|", deparse(substitute(z))), ""),
-        collapse = " + ")
+  htest$data.name = paste(xlab, "~", ylab,
+        ifelse(length(z) > 0, paste("|", zlab), ""))
 
   return(htest)
 
-}#CI.TEST.NUMERIC
-
-# do a single conditional independence test (factor objects).
-ci.test.factor = function(x, y = NULL, z = NULL, test = NULL, B = NULL,
-    debug = FALSE, ...) {
-
-  # check debug.
-  check.logical(debug)
-  # check the variables involved in the test.
-  if (!is.factor(y) && !(is.matrix(y) && ncol(y) == 1))
-    stop("'y' must be a factor vector.")
-  if (length(y) != length(x))
-    stop("'x' and 'y' must have the same length.")
-  if (!is.null(z)) {
-
-    if (is.matrix(z) || is.data.frame(z)) {
-
-      if (nrow(z) != length(x))
-        stop("'x', 'y', and 'z' must have the same length.")
-      if (!(data.type(z) %in% c("factor", "ordered", "mixed-do")))
-        stop("'z' must be a factor matrix or data frame.")
-
-      sx = 3:(2 + ncol(z))
-
-    }#THEN
-    else if (is.factor(z)) {
-
-      if (length(z) != length(x))
-        stop("'x', 'y', and 'z' must have the same length.")
-
-      sx = 3L
-
-    }#THEN
-    else
-      stop("'z' must be a factor vector, matrix or data frame.")
-
-    # build the data frame.
-    data = data.frame(x = x, y = y, z = z)
-
-  }#THEN
-  else {
-
-    # build the data frame.
-    data = data.frame(x = x, y = y)
-
-    sx = integer(0)
-
-  }#ELSE
-  # check the data are there.
-  check.data(data)
-  # check the test label.
-  test = check.test(test, data)
-  # check B (the number of permutation samples).
-  B = check.B(B, test)
-  # warn about unused arguments.
-  check.unused.args(list(...), character(0))
-
-  # create the htest object.
-  htest = indep.test(x = 1L, y = 2L, sx = as.integer(sx), data = data,
-    test = test, B = B, alpha = 1, learning = FALSE)
-  htest$method = test.labels[test]
-  htest$data.name = paste(deparse(substitute(x)), "~", deparse(substitute(y)),
-        ifelse(!is.null(z), paste("|", deparse(substitute(z))), ""),
-        collapse = " + ")
-
-  return(htest)
-
-}#CI.TEST.FACTOR
-
-ci.test.default = function(x, ...) {
-
-  stop("x must be either a factor object, a numeric vector, a character string or a data frame.")
-
-}#CI.TEST.DEFAULT
+}#CI.TEST.VECTOR
 
