@@ -1,7 +1,7 @@
 
 # conditional and unconditional independence tests (vectorized in x, scalar
 # in y).
-indep.test = function(x, y, sx, data, test, B = 0, alpha = 1, learning = TRUE) {
+indep.test = function(x, y, sx, data, test, B = 0L, alpha = 1, learning = TRUE) {
 
   .Call("indep_test",
         x = x,
@@ -17,7 +17,7 @@ indep.test = function(x, y, sx, data, test, B = 0, alpha = 1, learning = TRUE) {
 
 # test against all possible subsets of the conditioning set (scalar in both x
 # and y).
-allsubs.test = function(x, y, sx, fixed = character(0), data, test, B = 0,
+allsubs.test = function(x, y, sx, fixed = character(0), data, test, B = 0L,
     alpha = 1, min = 0, max = length(sx), debug = FALSE) {
 
   sx = sx[sx != ""]
@@ -39,6 +39,25 @@ allsubs.test = function(x, y, sx, fixed = character(0), data, test, B = 0,
 
 }#ALLSUBS.TEST
 
+# test each variable in turn given the rest as a conditioning set.
+roundrobin.test = function(x, z, fixed, data, test, B = 0L, alpha = 1,
+    debug = FALSE) {
+
+  if (length(z) == 0)
+    return(structure(numeric(0), names = character(0)))
+
+  .Call("roundrobin_test",
+        x = x,
+        z = z,
+        fixed = fixed,
+        data = data,
+        test = test,
+        B = B,
+        alpha = alpha,
+        debug = debug)
+
+}#ROUNDROBIN.TEST
+
 # Mutual Information (discrete data)
 mi.test = function(x, y, ndata, gsquare = TRUE, adjusted = FALSE) {
 
