@@ -6,7 +6,7 @@
 
 SEXP smart_network_averaging(SEXP arcs, SEXP nodes, SEXP weights) {
 
-int k = 0, from = 0, to = 0, nrows = length(arcs) / 2, dims = length(nodes);
+int k = 0, from = 0, to = 0, nrow = length(arcs) / 2, dims = length(nodes);
 int *a = NULL, *coords = NULL, *poset = NULL, *path = NULL, *scratch = NULL;
 double *w = NULL;
 SEXP weights2, amat, try, acyclic;
@@ -25,20 +25,20 @@ SEXP weights2, amat, try, acyclic;
   w = REAL(weights2);
 
   /* sort the strength coefficients. */
-  poset = Calloc1D(nrows, sizeof(int));
-  for (k = 0; k < nrows; k++)
+  poset = Calloc1D(nrow, sizeof(int));
+  for (k = 0; k < nrow; k++)
     poset[k] = k;
-  R_qsort_I(w, poset, 1, nrows);
+  R_qsort_I(w, poset, 1, nrow);
 
   /* allocate buffers for c_has_path(). */
   path = Calloc1D(dims, sizeof(int));
   scratch = Calloc1D(dims, sizeof(int));
 
   /* iterate over the arcs in reverse order wrt their strength coefficients. */
-  for (k = 0; k < nrows; k++) {
+  for (k = 0; k < nrow; k++) {
 
     from = coords[poset[k]] - 1;
-    to = coords[poset[k] + nrows] - 1;
+    to = coords[poset[k] + nrow] - 1;
 
     /* add an arc only if it does not introduce cycles. */
     if (!c_has_path(to, from, a, dims, nodes, FALSE, TRUE, path, scratch, FALSE))
@@ -64,7 +64,7 @@ SEXP weights2, amat, try, acyclic;
 
 /* mean strength for p-values and score deltas. */
 static void mean_strength_overall(SEXP *mean_df, SEXP strength, SEXP nodes,
-  int nrows, int nstr, SEXP ref_hash, double *w) {
+  int nrow, int nstr, SEXP ref_hash, double *w) {
 
 int i = 0, j = 0, *t = NULL;
 double *mstr = NULL, *cur_strength = NULL;
@@ -72,10 +72,10 @@ long double cumw = 0;
 SEXP mean_str, cur, cur_hash, try;
 
   /* allocate the strength accumulator vector. */
-  PROTECT(mean_str = allocVector(REALSXP, nrows));
+  PROTECT(mean_str = allocVector(REALSXP, nrow));
   SET_VECTOR_ELT(*mean_df, 2, mean_str);
   mstr = REAL(mean_str);
-  memset(mstr, '\0', nrows * sizeof(double));
+  memset(mstr, '\0', nrow * sizeof(double));
 
   for (i = 0; i < nstr; i++) {
 
@@ -90,7 +90,7 @@ SEXP mean_str, cur, cur_hash, try;
     PROTECT(try = match(ref_hash, cur_hash, 0));
     t = INTEGER(try);
 
-    for (j = 0; j < nrows; j++)
+    for (j = 0; j < nrow; j++)
       mstr[t[j] - 1] += w[i] * cur_strength[j];
 
     /* update the total weight mass. */
@@ -101,7 +101,7 @@ SEXP mean_str, cur, cur_hash, try;
   }/*FOR*/
 
   /* rescale by the total weight mass. */
-  for (j = 0; j < nrows; j++)
+  for (j = 0; j < nrow; j++)
     mstr[j] /= cumw;
 
   UNPROTECT(1);
@@ -110,7 +110,7 @@ SEXP mean_str, cur, cur_hash, try;
 
 /* mean strength for bootstrap probabilities. */
 static void mean_strength_direction(SEXP *mean_df, SEXP strength, SEXP nodes,
-  int nrows, int nstr, SEXP ref_hash, double *w) {
+  int nrow, int nstr, SEXP ref_hash, double *w) {
 
 int i = 0, j = 0, *t = NULL, nnodes = length(nodes);
 double *mstr = NULL, *mdir = NULL, *cur_strength = NULL, *cur_dir = NULL;
@@ -120,14 +120,14 @@ SEXP mean_str, mean_dir, cur, cur_hash, try;
 
 
   /* allocate vectors for strength and direction. */
-  PROTECT(mean_str = allocVector(REALSXP, nrows));
+  PROTECT(mean_str = allocVector(REALSXP, nrow));
   SET_VECTOR_ELT(*mean_df, 2, mean_str);
   mstr = REAL(mean_str);
-  memset(mstr, '\0', nrows * sizeof(double));
-  PROTECT(mean_dir = allocVector(REALSXP, nrows));
+  memset(mstr, '\0', nrow * sizeof(double));
+  PROTECT(mean_dir = allocVector(REALSXP, nrow));
   SET_VECTOR_ELT(*mean_df, 3, mean_dir);
   mdir = REAL(mean_dir);
-  memset(mdir, '\0', nrows * sizeof(double));
+  memset(mdir, '\0', nrow * sizeof(double));
 
   for (i = 0; i < nstr; i++) {
 
@@ -143,7 +143,7 @@ SEXP mean_str, mean_dir, cur, cur_hash, try;
     PROTECT(try = match(ref_hash, cur_hash, 0));
     t = INTEGER(try);
 
-    for (j = 0; j < nrows; j++)
+    for (j = 0; j < nrow; j++)
       mstr[t[j] - 1] += w[i] * (cur_strength[j] * cur_dir[j]);
 
     /* update the total weight mass. */
@@ -154,7 +154,7 @@ SEXP mean_str, mean_dir, cur, cur_hash, try;
   }/*FOR*/
 
   /* rescale by the total weight mass. */
-  for (j = 0; j < nrows; j++)
+  for (j = 0; j < nrow; j++)
     mstr[j] /= cumw;
 
   /* split arc strength from direction strength. */
@@ -190,17 +190,17 @@ SEXP mean_str, mean_dir, cur, cur_hash, try;
 /* average multiple bn.strength objects, with weights. */
 SEXP mean_strength(SEXP strength, SEXP nodes, SEXP weights) {
 
-int nstr = length(weights), ncols = 0, nrows = 0;
+int nstr = length(weights), ncol = 0, nrow = 0;
 double *w = REAL(weights);
 const char *m = NULL;
 SEXP ref, ref_hash, mean_df, method;
 
   /* initialize the result using the first bn.strength object as a reference. */
   ref = VECTOR_ELT(strength, 0);
-  ncols = length(ref);
-  nrows = length(VECTOR_ELT(ref, 0));
+  ncol = length(ref);
+  nrow = length(VECTOR_ELT(ref, 0));
 
-  PROTECT(mean_df = allocVector(VECSXP, ncols));
+  PROTECT(mean_df = allocVector(VECSXP, ncol));
   setAttrib(mean_df, R_NamesSymbol, getAttrib(ref, R_NamesSymbol));
   SET_VECTOR_ELT(mean_df, 0, VECTOR_ELT(ref, 0));
   SET_VECTOR_ELT(mean_df, 1, VECTOR_ELT(ref, 1));
@@ -215,9 +215,9 @@ SEXP ref, ref_hash, mean_df, method;
   m = CHAR(STRING_ELT(method, 0));
 
   if ((strcmp(m, "score") == 0) || (strcmp(m, "test") == 0))
-    mean_strength_overall(&mean_df, strength, nodes, nrows, nstr, ref_hash, w);
+    mean_strength_overall(&mean_df, strength, nodes, nrow, nstr, ref_hash, w);
   else if (strcmp(m, "bootstrap") == 0)
-    mean_strength_direction(&mean_df, strength, nodes, nrows, nstr, ref_hash, w);
+    mean_strength_direction(&mean_df, strength, nodes, nrow, nstr, ref_hash, w);
 
   UNPROTECT(2);
 
