@@ -1,5 +1,22 @@
 #include "include/rcore.h"
 #include "include/matrix.h"
+#include "include/sets.h"
+
+/* class check to match that in the R code. */
+int c_is(SEXP obj, const char *str) {
+
+int i = 0;
+SEXP class;
+
+  class = getAttrib(obj, R_ClassSymbol);
+
+  for (i = 0; i < length(class); i++)
+    if (!strcmp(CHAR(STRING_ELT(class, i)), str))
+      return TRUE;
+
+  return FALSE;
+
+}/*C_IS*/
 
 /* get the list element named str, or return NULL. */
 SEXP getListElement(SEXP list, char *str) {
@@ -129,40 +146,19 @@ SEXP result, levels, lvls;
 }/*INT2FAC*/
 
 /* efficient copying of data from the data frame to a matrix for the QR decomposition. */
-SEXP qr_matrix(SEXP dataframe, SEXP name) {
+void c_qr_matrix(double *qr, double **x, int nrow, int ncol) {
 
-SEXP try, result, colnames = getAttrib(dataframe, R_NamesSymbol);
-int i = 0, ncols = length(name), nrows = length(VECTOR_ELT(dataframe, 0));
-int *idx = NULL;
-double *res = NULL, *source = NULL;
-
-  PROTECT(try = match(colnames, name, 0));
-  idx = INTEGER(try);
-
-  PROTECT(result = allocMatrix(REALSXP, nrows, ncols + 1));
-  res = REAL(result);
+int i = 0;
 
   /* fill the intercept column. */
-  for (i = 0; i < nrows; i++)
-    res[i] = 1;
+  for (i = 0; i < nrow; i++)
+    qr[i] = 1;
 
-  /* copy the data from the data frame. */
-  for (i = 0; i < ncols; i++) {
+  /* copy the data to the right comun of the matrix. */
+  for (i = 0; i < ncol; i++)
+    memcpy(qr + (i + 1) * nrow, x[i], nrow * sizeof(double));
 
-    /* shift to the beginning of the column. */
-    res += nrows;
-    /* extract the right column from the data frame. */
-    source = REAL(VECTOR_ELT(dataframe, idx[i] -1));
-    /* copy the data to the right comun of the matrix. */
-    memcpy(res, source, nrows * sizeof(double));
-
-  }/*FOR*/
-
-  UNPROTECT(2);
-
-  return result;
-
-}/*QR_MATRIX*/
+}/*C_QR_MATRIX*/
 
 /* inverse function of the UPTRI3() macro. */
 void INV_UPTRI3(int x, int n, int *res) {
@@ -193,7 +189,7 @@ int c = 0, r = 0, cn = n - 1;
 /* normalize a conditional probability table. */
 SEXP normalize_cpt(SEXP cpt) {
 
-int i = 0, j = 0, nrows = 0, cells = length(cpt);
+int i = 0, j = 0, nrow = 0, cells = length(cpt);
 short int duplicated = 0;
 double psum = 0;
 double *c = NULL;
@@ -204,18 +200,18 @@ double *c = NULL;
   /* ... and dereference it. */
   c = REAL(cpt);
 
-  nrows = INT(getAttrib(cpt, R_DimSymbol));
+  nrow = INT(getAttrib(cpt, R_DimSymbol));
 
-  for (j = 0; j < (cells/nrows); j++) {
+  for (j = 0; j < (cells/nrow); j++) {
 
     /* reset column total counter. */
     psum = 0;
     /* compute the new column total. */
-    for (i = 0; i < nrows; i++)
-      psum += c[CMC(i, j, nrows)];
+    for (i = 0; i < nrow; i++)
+      psum += c[CMC(i, j, nrow)];
     /* divide by the new column total. */
-    for (i = 0; i < nrows; i++)
-      c[CMC(i, j, nrows)] /= psum;
+    for (i = 0; i < nrow; i++)
+      c[CMC(i, j, nrow)] /= psum;
 
   }/*FOR*/
 
@@ -270,10 +266,80 @@ void setDimNames(SEXP obj, SEXP rownames, SEXP colnames) {
 
 SEXP dimnames;
 
+  PROTECT(rownames);
+  PROTECT(colnames);
   PROTECT(dimnames = allocVector(VECSXP, 2));
   SET_VECTOR_ELT(dimnames, 0, rownames);
   SET_VECTOR_ELT(dimnames, 1, colnames);
   setAttrib(obj, R_DimNamesSymbol, dimnames);
-  UNPROTECT(1);
+  UNPROTECT(3);
 
 }/*SETDIMNAMES*/
+
+/* minimal implementation of table(). */
+SEXP minimal_table(SEXP dataframe) {
+
+int i = 0, nrow = length(VECTOR_ELT(dataframe, 0)), ncol = length(dataframe);
+int *dd = NULL, *tt = NULL, **columns = NULL, *cfg = NULL;
+double ncells = 1;
+SEXP table, dims, dimnames, cur;
+
+  /* prepare the dimensions. */
+  PROTECT(dims = allocVector(INTSXP, ncol));
+  dd = INTEGER(dims);
+  PROTECT(dimnames = allocVector(VECSXP, ncol));
+  setAttrib(dimnames, R_NamesSymbol, getAttrib(dataframe, R_NamesSymbol));
+
+  /* dereference the data frame, extract the levels. */
+  columns = (int **) Calloc1D(ncol, sizeof(int *));
+
+  for (i = 0; i < ncol ; i++) {
+
+    /* extract the column from the data frame... */
+    cur = VECTOR_ELT(dataframe, i);
+    /* ... dereference it... */
+    columns[i] = INTEGER(cur);
+    /* ... extract the number of levels... */
+    dd[i] = NLEVELS(cur);
+    /* ... and save them in the table dimensions. */
+    SET_VECTOR_ELT(dimnames, i, getAttrib(cur, R_LevelsSymbol));
+
+    ncells *= dd[i];
+
+  }/*FOR*/
+
+  if (ncells > INT_MAX) {
+
+    Free1D(columns);
+
+    UNPROTECT(2);
+
+    error("attempting to create a table with more than INT_MAX cells.");
+
+  }/*THEN*/
+
+  /* allocate and dereference the table. */
+  PROTECT(table = allocVector(INTSXP, ncells));
+  tt = INTEGER(table);
+  memset(tt, '\0', ncells * sizeof(int));
+
+  /* prepare the configurations. */
+  cfg = Calloc1D(nrow, sizeof(int));
+  c_fast_config(columns, nrow, ncol, dd, cfg, NULL, 0);
+
+  for (i = 0; i < nrow; i++)
+    tt[cfg[i]]++;
+
+  /* set the attributess for class and dimensions. */
+  setAttrib(table, R_ClassSymbol, mkString("table"));
+  setAttrib(table, R_DimSymbol, dims);
+  setAttrib(table, R_DimNamesSymbol, dimnames);   
+
+  UNPROTECT(3);
+
+  Free1D(columns);
+  Free1D(cfg);
+
+  return table;
+
+}/*MINIMAL_TABLE*/
